from sklearn.metrics import (
    recall_score
)

def calculate_equal_opportunity(clf, X_test_advantaged_group, 
y_test_advantaged_group,X_test_disadvantaged_group, y_test_disadvantaged_group 
):
    """
    Function calculates equal opportunity
    """
    pred_adv = clf.predict(X_test_advantaged_group)
    recall_advantaged_group = recall_score(y_test_advantaged_group, pred_adv)
    
    pred_disadv = clf.predict(X_test_disadvantaged_group)
    recall_disadvantaged_group = recall_score(y_test_disadvantaged_group, pred_disadv)

    equal_opportunity = recall_disadvantaged_group - recall_advantaged_group

    return equal_opportunity


from sklearn.metrics import (
    roc_auc_score
)

def calculate_abroca(clf, X_test_advantaged_group, 
y_test_advantaged_group,X_test_disadvantaged_group, y_test_disadvantaged_group 
):
    """
    Function calculates abroca
    """
    pred_adv = clf.predict(X_test_advantaged_group)
    auc_advantaged_group = roc_auc_score(y_test_advantaged_group, pred_adv)

    pred_disadv = clf.predict(X_test_disadvantaged_group)
    auc_disadvantaged_group = roc_auc_score(y_test_disadvantaged_group, pred_disadv)

    abroca = auc_advantaged_group - auc_disadvantaged_group

    return abroca



from sklearn.metrics import (
    precision_score
)

def calculate_predictive_parity(clf, X_test_advantaged_group, 
y_test_advantaged_group,X_test_disadvantaged_group, y_test_disadvantaged_group 
):
    """
    Function calculates predictive parity
    """
    pred_adv = clf.predict(X_test_advantaged_group)
    predicison_advantaged_group = precision_score(y_test_advantaged_group, pred_adv)

    pred_disadv = clf.predict(X_test_disadvantaged_group)
    predicison_disadvantaged_group = precision_score(y_test_disadvantaged_group, pred_disadv)

    predictive_parity = predicison_advantaged_group - predicison_disadvantaged_group

    return predictive_parity
